tet-ris 0.5.1

A play a quick game of 1984-ish Tetris right in the terminal!
tet-ris-0.5.1 is not a library.

tet-ris

Build Status Build Status Build Status Downloads Version License

Civil-War-Reenactment Style of Tetris 1984 (with some quality-of-life improvements) in Rust!

demo

Installation

cargo install tet-ris

or

$ git clone https://github.com/manorajesh/tet-ris.git
$ cargo build --release

Usage

tet-ris

-h Output

Play Tetris 1984ish in your terminal!

Usage: tet-ris [OPTIONS]

Options:
  -g, --ghost                Disable ghost piece shown at the bottom of the board
  -c, --hold                 Disable hold piece with 'c' key
  -t, --tick <MILLISECONDS>  Gravity speed for the game [default: 10]
  -s, --save <FILE>          path to save file [default: save.tetris]
  -h, --help                 Print help (see more with '--help')
  -V, --version              Print version

How to Play

The objective of Tetris is to move and rotate falling pieces called tetrominoes in order to create complete horizontal lines. When a line is complete, it will be cleared, and the lines above it will drop down. The game becomes progressively faster as you clear more lines and level up.

Controls

  • Left Arrow: Move the active piece left.
  • Right Arrow: Move the active piece right.
  • Down Arrow: Move the active piece down (soft drop).
  • Up Arrow: Rotate the active piece clockwise.
  • Space: Hard drop the active piece.
  • C: Hold the active piece.
  • P: Pause the game.
  • Q: Quit the game.

Gameplay Images